@@ -107,7 +107,6 @@ def data(
     DataFrame, DataFrame, DataFrame
         If test_size > 0 and split==True, then training, validation, and test DataFrames are returned.
     """
-
     train_csv = open_text(module, fname)
     df = pd.read_csv(train_csv)
 
@@ -251,6 +250,12 @@ class Model:
             learning_time = epoch_check and self.epoch >= swa_check
             if learning_time:
                 act_v, pred_v, _, _ = self.predict(loader=self.data_loader)
+                if np.any(np.isnan(pred_v)):
+                    warn(
+                        "NaN values found in `pred_v`. Replacing with DummyRegressor() values (i.e. mean of training targets)."
+                    )
+                    pred_v = np.nan_to_num(pred_v, nan=np.mean(y))
+                mae_v = mean_absolute_error(act_v, pred_v)
                 mae_v = mean_absolute_error(act_v, pred_v)
                 self.optimizer.update_swa(mae_v)
                 minima.append(self.optimizer.minimum_found)
